# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from telnyx import Telnyx, AsyncTelnyx
from tests.utils import assert_matches_type
from telnyx.pagination import SyncDefaultFlatPagination, AsyncDefaultFlatPagination
from telnyx.types.ai.assistants import (
    AssistantTest,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestTests:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create(self, client: Telnyx) -> None:
        test = client.ai.assistants.tests.create(
            destination="+15551234567",
            instructions="Act as a frustrated customer who received a damaged product. Ask for a refund and escalate if not satisfied with the initial response.",
            name="Customer Support Bot Test",
            rubric=[
                {
                    "criteria": "Assistant responds within 30 seconds",
                    "name": "Response Time",
                },
                {
                    "criteria": "Provides correct product information",
                    "name": "Accuracy",
                },
            ],
        )
        assert_matches_type(AssistantTest, test, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_with_all_params(self, client: Telnyx) -> None:
        test = client.ai.assistants.tests.create(
            destination="+15551234567",
            instructions="Act as a frustrated customer who received a damaged product. Ask for a refund and escalate if not satisfied with the initial response.",
            name="Customer Support Bot Test",
            rubric=[
                {
                    "criteria": "Assistant responds within 30 seconds",
                    "name": "Response Time",
                },
                {
                    "criteria": "Provides correct product information",
                    "name": "Accuracy",
                },
            ],
            description="description",
            max_duration_seconds=1,
            telnyx_conversation_channel="web_chat",
            test_suite="test_suite",
        )
        assert_matches_type(AssistantTest, test, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: Telnyx) -> None:
        response = client.ai.assistants.tests.with_raw_response.create(
            destination="+15551234567",
            instructions="Act as a frustrated customer who received a damaged product. Ask for a refund and escalate if not satisfied with the initial response.",
            name="Customer Support Bot Test",
            rubric=[
                {
                    "criteria": "Assistant responds within 30 seconds",
                    "name": "Response Time",
                },
                {
                    "criteria": "Provides correct product information",
                    "name": "Accuracy",
                },
            ],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        test = response.parse()
        assert_matches_type(AssistantTest, test, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: Telnyx) -> None:
        with client.ai.assistants.tests.with_streaming_response.create(
            destination="+15551234567",
            instructions="Act as a frustrated customer who received a damaged product. Ask for a refund and escalate if not satisfied with the initial response.",
            name="Customer Support Bot Test",
            rubric=[
                {
                    "criteria": "Assistant responds within 30 seconds",
                    "name": "Response Time",
                },
                {
                    "criteria": "Provides correct product information",
                    "name": "Accuracy",
                },
            ],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            test = response.parse()
            assert_matches_type(AssistantTest, test, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: Telnyx) -> None:
        test = client.ai.assistants.tests.retrieve(
            "test_id",
        )
        assert_matches_type(AssistantTest, test, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: Telnyx) -> None:
        response = client.ai.assistants.tests.with_raw_response.retrieve(
            "test_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        test = response.parse()
        assert_matches_type(AssistantTest, test, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: Telnyx) -> None:
        with client.ai.assistants.tests.with_streaming_response.retrieve(
            "test_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            test = response.parse()
            assert_matches_type(AssistantTest, test, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `test_id` but received ''"):
            client.ai.assistants.tests.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update(self, client: Telnyx) -> None:
        test = client.ai.assistants.tests.update(
            test_id="test_id",
        )
        assert_matches_type(AssistantTest, test, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update_with_all_params(self, client: Telnyx) -> None:
        test = client.ai.assistants.tests.update(
            test_id="test_id",
            description="description",
            destination="x",
            instructions="x",
            max_duration_seconds=1,
            name="x",
            rubric=[
                {
                    "criteria": "criteria",
                    "name": "name",
                }
            ],
            telnyx_conversation_channel="phone_call",
            test_suite="test_suite",
        )
        assert_matches_type(AssistantTest, test, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_update(self, client: Telnyx) -> None:
        response = client.ai.assistants.tests.with_raw_response.update(
            test_id="test_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        test = response.parse()
        assert_matches_type(AssistantTest, test, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_update(self, client: Telnyx) -> None:
        with client.ai.assistants.tests.with_streaming_response.update(
            test_id="test_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            test = response.parse()
            assert_matches_type(AssistantTest, test, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_update(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `test_id` but received ''"):
            client.ai.assistants.tests.with_raw_response.update(
                test_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list(self, client: Telnyx) -> None:
        test = client.ai.assistants.tests.list()
        assert_matches_type(SyncDefaultFlatPagination[AssistantTest], test, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: Telnyx) -> None:
        test = client.ai.assistants.tests.list(
            destination="destination",
            page_number=0,
            page_size=0,
            telnyx_conversation_channel="telnyx_conversation_channel",
            test_suite="test_suite",
        )
        assert_matches_type(SyncDefaultFlatPagination[AssistantTest], test, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Telnyx) -> None:
        response = client.ai.assistants.tests.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        test = response.parse()
        assert_matches_type(SyncDefaultFlatPagination[AssistantTest], test, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Telnyx) -> None:
        with client.ai.assistants.tests.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            test = response.parse()
            assert_matches_type(SyncDefaultFlatPagination[AssistantTest], test, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_delete(self, client: Telnyx) -> None:
        test = client.ai.assistants.tests.delete(
            "test_id",
        )
        assert test is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_delete(self, client: Telnyx) -> None:
        response = client.ai.assistants.tests.with_raw_response.delete(
            "test_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        test = response.parse()
        assert test is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_delete(self, client: Telnyx) -> None:
        with client.ai.assistants.tests.with_streaming_response.delete(
            "test_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            test = response.parse()
            assert test is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_delete(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `test_id` but received ''"):
            client.ai.assistants.tests.with_raw_response.delete(
                "",
            )


class TestAsyncTests:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncTelnyx) -> None:
        test = await async_client.ai.assistants.tests.create(
            destination="+15551234567",
            instructions="Act as a frustrated customer who received a damaged product. Ask for a refund and escalate if not satisfied with the initial response.",
            name="Customer Support Bot Test",
            rubric=[
                {
                    "criteria": "Assistant responds within 30 seconds",
                    "name": "Response Time",
                },
                {
                    "criteria": "Provides correct product information",
                    "name": "Accuracy",
                },
            ],
        )
        assert_matches_type(AssistantTest, test, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncTelnyx) -> None:
        test = await async_client.ai.assistants.tests.create(
            destination="+15551234567",
            instructions="Act as a frustrated customer who received a damaged product. Ask for a refund and escalate if not satisfied with the initial response.",
            name="Customer Support Bot Test",
            rubric=[
                {
                    "criteria": "Assistant responds within 30 seconds",
                    "name": "Response Time",
                },
                {
                    "criteria": "Provides correct product information",
                    "name": "Accuracy",
                },
            ],
            description="description",
            max_duration_seconds=1,
            telnyx_conversation_channel="web_chat",
            test_suite="test_suite",
        )
        assert_matches_type(AssistantTest, test, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.assistants.tests.with_raw_response.create(
            destination="+15551234567",
            instructions="Act as a frustrated customer who received a damaged product. Ask for a refund and escalate if not satisfied with the initial response.",
            name="Customer Support Bot Test",
            rubric=[
                {
                    "criteria": "Assistant responds within 30 seconds",
                    "name": "Response Time",
                },
                {
                    "criteria": "Provides correct product information",
                    "name": "Accuracy",
                },
            ],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        test = await response.parse()
        assert_matches_type(AssistantTest, test, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.assistants.tests.with_streaming_response.create(
            destination="+15551234567",
            instructions="Act as a frustrated customer who received a damaged product. Ask for a refund and escalate if not satisfied with the initial response.",
            name="Customer Support Bot Test",
            rubric=[
                {
                    "criteria": "Assistant responds within 30 seconds",
                    "name": "Response Time",
                },
                {
                    "criteria": "Provides correct product information",
                    "name": "Accuracy",
                },
            ],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            test = await response.parse()
            assert_matches_type(AssistantTest, test, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncTelnyx) -> None:
        test = await async_client.ai.assistants.tests.retrieve(
            "test_id",
        )
        assert_matches_type(AssistantTest, test, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.assistants.tests.with_raw_response.retrieve(
            "test_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        test = await response.parse()
        assert_matches_type(AssistantTest, test, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.assistants.tests.with_streaming_response.retrieve(
            "test_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            test = await response.parse()
            assert_matches_type(AssistantTest, test, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `test_id` but received ''"):
            await async_client.ai.assistants.tests.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update(self, async_client: AsyncTelnyx) -> None:
        test = await async_client.ai.assistants.tests.update(
            test_id="test_id",
        )
        assert_matches_type(AssistantTest, test, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncTelnyx) -> None:
        test = await async_client.ai.assistants.tests.update(
            test_id="test_id",
            description="description",
            destination="x",
            instructions="x",
            max_duration_seconds=1,
            name="x",
            rubric=[
                {
                    "criteria": "criteria",
                    "name": "name",
                }
            ],
            telnyx_conversation_channel="phone_call",
            test_suite="test_suite",
        )
        assert_matches_type(AssistantTest, test, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.assistants.tests.with_raw_response.update(
            test_id="test_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        test = await response.parse()
        assert_matches_type(AssistantTest, test, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.assistants.tests.with_streaming_response.update(
            test_id="test_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            test = await response.parse()
            assert_matches_type(AssistantTest, test, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_update(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `test_id` but received ''"):
            await async_client.ai.assistants.tests.with_raw_response.update(
                test_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncTelnyx) -> None:
        test = await async_client.ai.assistants.tests.list()
        assert_matches_type(AsyncDefaultFlatPagination[AssistantTest], test, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncTelnyx) -> None:
        test = await async_client.ai.assistants.tests.list(
            destination="destination",
            page_number=0,
            page_size=0,
            telnyx_conversation_channel="telnyx_conversation_channel",
            test_suite="test_suite",
        )
        assert_matches_type(AsyncDefaultFlatPagination[AssistantTest], test, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.assistants.tests.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        test = await response.parse()
        assert_matches_type(AsyncDefaultFlatPagination[AssistantTest], test, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.assistants.tests.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            test = await response.parse()
            assert_matches_type(AsyncDefaultFlatPagination[AssistantTest], test, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_delete(self, async_client: AsyncTelnyx) -> None:
        test = await async_client.ai.assistants.tests.delete(
            "test_id",
        )
        assert test is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.assistants.tests.with_raw_response.delete(
            "test_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        test = await response.parse()
        assert test is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.assistants.tests.with_streaming_response.delete(
            "test_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            test = await response.parse()
            assert test is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_delete(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `test_id` but received ''"):
            await async_client.ai.assistants.tests.with_raw_response.delete(
                "",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel

__all__ = ["OAuthRetrieveJwksResponse", "Key"]


class Key(BaseModel):
    alg: Optional[str] = None
    """Algorithm"""

    kid: Optional[str] = None
    """Key ID"""

    kty: Optional[str] = None
    """Key type"""

    use: Optional[str] = None
    """Key use"""


class OAuthRetrieveJwksResponse(BaseModel):
    keys: Optional[List[Key]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .record import Record
from .._models import BaseModel
from .network_interface import NetworkInterface

__all__ = ["NetworkListInterfacesResponse", "NetworkListInterfacesResponseRegion"]


class NetworkListInterfacesResponseRegion(BaseModel):
    code: Optional[str] = None
    """Region code of the interface."""

    name: Optional[str] = None
    """Region name of the interface."""

    record_type: Optional[str] = None
    """Identifies the type of the resource."""


class NetworkListInterfacesResponse(Record, NetworkInterface):
    record_type: Optional[str] = None  # type: ignore
    """Identifies the type of the resource."""

    region: Optional[NetworkListInterfacesResponseRegion] = None

    region_code: Optional[str] = None
    """The region interface is deployed to."""

    type: Optional[str] = None
    """Identifies the type of the interface."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["WirelessBlocklist"]


class WirelessBlocklist(BaseModel):
    id: Optional[str] = None
    """Identifies the resource."""

    created_at: Optional[str] = None
    """ISO 8601 formatted date-time indicating when the resource was created."""

    name: Optional[str] = None
    """The wireless blocklist name."""

    record_type: Optional[str] = None

    type: Optional[Literal["country", "mcc", "plmn"]] = None
    """The type of the wireless blocklist."""

    updated_at: Optional[str] = None
    """ISO 8601 formatted date-time indicating when the resource was updated."""

    values: Optional[List[str]] = None
    """Values to block. The values here depend on the `type` of Wireless Blocklist."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import TYPE_CHECKING, Dict, List, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["VerifyProfile", "Call", "Flashcall", "SMS"]


class Call(BaseModel):
    app_name: Optional[str] = None
    """
    The name that identifies the application requesting 2fa in the verification
    message.
    """

    code_length: Optional[int] = None
    """The length of the verify code to generate."""

    default_verification_timeout_secs: Optional[int] = None
    """
    For every request that is initiated via this Verify profile, this sets the
    number of seconds before a verification request code expires. Once the
    verification request expires, the user cannot use the code to verify their
    identity.
    """

    messaging_template_id: Optional[str] = None
    """The message template identifier selected from /verify_profiles/templates"""

    whitelisted_destinations: Optional[List[str]] = None
    """Enabled country destinations to send verification codes.

    The elements in the list must be valid ISO 3166-1 alpha-2 country codes. If set
    to `["*"]`, all destinations will be allowed.
    """

    if TYPE_CHECKING:
        # Some versions of Pydantic <2.8.0 have a bug and don’t allow assigning a
        # value to this field, so for compatibility we avoid doing it at runtime.
        __pydantic_extra__: Dict[str, object] = FieldInfo(init=False)  # pyright: ignore[reportIncompatibleVariableOverride]

        # Stub to indicate that arbitrary properties are accepted.
        # To access properties that are not valid identifiers you can use `getattr`, e.g.
        # `getattr(obj, '$type')`
        def __getattr__(self, attr: str) -> object: ...
    else:
        __pydantic_extra__: Dict[str, object]


class Flashcall(BaseModel):
    default_verification_timeout_secs: Optional[int] = None
    """
    For every request that is initiated via this Verify profile, this sets the
    number of seconds before a verification request code expires. Once the
    verification request expires, the user cannot use the code to verify their
    identity.
    """

    if TYPE_CHECKING:
        # Some versions of Pydantic <2.8.0 have a bug and don’t allow assigning a
        # value to this field, so for compatibility we avoid doing it at runtime.
        __pydantic_extra__: Dict[str, object] = FieldInfo(init=False)  # pyright: ignore[reportIncompatibleVariableOverride]

        # Stub to indicate that arbitrary properties are accepted.
        # To access properties that are not valid identifiers you can use `getattr`, e.g.
        # `getattr(obj, '$type')`
        def __getattr__(self, attr: str) -> object: ...
    else:
        __pydantic_extra__: Dict[str, object]


class SMS(BaseModel):
    alpha_sender: Optional[str] = None
    """
    The alphanumeric sender ID to use when sending to destinations that require an
    alphanumeric sender ID.
    """

    app_name: Optional[str] = None
    """
    The name that identifies the application requesting 2fa in the verification
    message.
    """

    code_length: Optional[int] = None
    """The length of the verify code to generate."""

    default_verification_timeout_secs: Optional[int] = None
    """
    For every request that is initiated via this Verify profile, this sets the
    number of seconds before a verification request code expires. Once the
    verification request expires, the user cannot use the code to verify their
    identity.
    """

    messaging_template_id: Optional[str] = None
    """The message template identifier selected from /verify_profiles/templates"""

    whitelisted_destinations: Optional[List[str]] = None
    """Enabled country destinations to send verification codes.

    The elements in the list must be valid ISO 3166-1 alpha-2 country codes. If set
    to `["*"]`, all destinations will be allowed.
    """

    if TYPE_CHECKING:
        # Some versions of Pydantic <2.8.0 have a bug and don’t allow assigning a
        # value to this field, so for compatibility we avoid doing it at runtime.
        __pydantic_extra__: Dict[str, object] = FieldInfo(init=False)  # pyright: ignore[reportIncompatibleVariableOverride]

        # Stub to indicate that arbitrary properties are accepted.
        # To access properties that are not valid identifiers you can use `getattr`, e.g.
        # `getattr(obj, '$type')`
        def __getattr__(self, attr: str) -> object: ...
    else:
        __pydantic_extra__: Dict[str, object]


class VerifyProfile(BaseModel):
    id: Optional[str] = None

    call: Optional[Call] = None

    created_at: Optional[str] = None

    flashcall: Optional[Flashcall] = None

    language: Optional[str] = None

    name: Optional[str] = None

    record_type: Optional[Literal["verification_profile"]] = None
    """The possible verification profile record types."""

    sms: Optional[SMS] = None

    updated_at: Optional[str] = None

    webhook_failover_url: Optional[str] = None

    webhook_url: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["ActionGatherUsingAudioParams"]


class ActionGatherUsingAudioParams(TypedDict, total=False):
    audio_url: str
    """The URL of a file to be played back at the beginning of each prompt.

    The URL can point to either a WAV or MP3 file. media_name and audio_url cannot
    be used together in one request.
    """

    client_state: str
    """Use this field to add state to every subsequent webhook.

    It must be a valid Base-64 encoded string.
    """

    command_id: str
    """Use this field to avoid duplicate commands.

    Telnyx will ignore any command with the same `command_id` for the same
    `call_control_id`.
    """

    inter_digit_timeout_millis: int
    """The number of milliseconds to wait for input between digits."""

    invalid_audio_url: str
    """
    The URL of a file to play when digits don't match the `valid_digits` parameter
    or the number of digits is not between `min` and `max`. The URL can point to
    either a WAV or MP3 file. invalid_media_name and invalid_audio_url cannot be
    used together in one request.
    """

    invalid_media_name: str
    """
    The media_name of a file to be played back when digits don't match the
    `valid_digits` parameter or the number of digits is not between `min` and `max`.
    The media_name must point to a file previously uploaded to
    api.telnyx.com/v2/media by the same user/organization. The file must either be a
    WAV or MP3 file.
    """

    maximum_digits: int
    """The maximum number of digits to fetch.

    This parameter has a maximum value of 128.
    """

    maximum_tries: int
    """
    The maximum number of times the file should be played if there is no input from
    the user on the call.
    """

    media_name: str
    """The media_name of a file to be played back at the beginning of each prompt.

    The media_name must point to a file previously uploaded to
    api.telnyx.com/v2/media by the same user/organization. The file must either be a
    WAV or MP3 file.
    """

    minimum_digits: int
    """The minimum number of digits to fetch. This parameter has a minimum value of 1."""

    terminating_digit: str
    """
    The digit used to terminate input if fewer than `maximum_digits` digits have
    been gathered.
    """

    timeout_millis: int
    """
    The number of milliseconds to wait for a DTMF response after file playback ends
    before a replaying the sound file.
    """

    valid_digits: str
    """A list of all digits accepted as valid."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .call_streaming_failed import CallStreamingFailed

__all__ = ["CallStreamingFailedWebhookEvent"]


class CallStreamingFailedWebhookEvent(BaseModel):
    data: Optional[CallStreamingFailed] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from telnyx import Telnyx, AsyncTelnyx
from tests.utils import assert_matches_type
from telnyx.pagination import SyncDefaultFlatPagination, AsyncDefaultFlatPagination
from telnyx.types.sim_cards import (
    SimCardAction,
    ActionEnableResponse,
    ActionDisableResponse,
    ActionRetrieveResponse,
    ActionSetStandbyResponse,
    ActionSetPublicIPResponse,
    ActionRemovePublicIPResponse,
    ActionBulkSetPublicIPsResponse,
    ActionValidateRegistrationCodesResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestActions:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: Telnyx) -> None:
        action = client.sim_cards.actions.retrieve(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )
        assert_matches_type(ActionRetrieveResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: Telnyx) -> None:
        response = client.sim_cards.actions.with_raw_response.retrieve(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = response.parse()
        assert_matches_type(ActionRetrieveResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: Telnyx) -> None:
        with client.sim_cards.actions.with_streaming_response.retrieve(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = response.parse()
            assert_matches_type(ActionRetrieveResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.sim_cards.actions.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list(self, client: Telnyx) -> None:
        action = client.sim_cards.actions.list()
        assert_matches_type(SyncDefaultFlatPagination[SimCardAction], action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: Telnyx) -> None:
        action = client.sim_cards.actions.list(
            filter={
                "action_type": "disable",
                "bulk_sim_card_action_id": "47a1c2b0-cc7b-4ab1-bb98-b33fb0fc61b9",
                "sim_card_id": "47a1c2b0-cc7b-4ab1-bb98-b33fb0fc61b9",
                "status": "in-progress",
            },
            page_number=0,
            page_size=0,
        )
        assert_matches_type(SyncDefaultFlatPagination[SimCardAction], action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Telnyx) -> None:
        response = client.sim_cards.actions.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = response.parse()
        assert_matches_type(SyncDefaultFlatPagination[SimCardAction], action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Telnyx) -> None:
        with client.sim_cards.actions.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = response.parse()
            assert_matches_type(SyncDefaultFlatPagination[SimCardAction], action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_bulk_set_public_ips(self, client: Telnyx) -> None:
        action = client.sim_cards.actions.bulk_set_public_ips(
            sim_card_ids=["6b14e151-8493-4fa1-8664-1cc4e6d14158"],
        )
        assert_matches_type(ActionBulkSetPublicIPsResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_bulk_set_public_ips(self, client: Telnyx) -> None:
        response = client.sim_cards.actions.with_raw_response.bulk_set_public_ips(
            sim_card_ids=["6b14e151-8493-4fa1-8664-1cc4e6d14158"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = response.parse()
        assert_matches_type(ActionBulkSetPublicIPsResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_bulk_set_public_ips(self, client: Telnyx) -> None:
        with client.sim_cards.actions.with_streaming_response.bulk_set_public_ips(
            sim_card_ids=["6b14e151-8493-4fa1-8664-1cc4e6d14158"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = response.parse()
            assert_matches_type(ActionBulkSetPublicIPsResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_disable(self, client: Telnyx) -> None:
        action = client.sim_cards.actions.disable(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )
        assert_matches_type(ActionDisableResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_disable(self, client: Telnyx) -> None:
        response = client.sim_cards.actions.with_raw_response.disable(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = response.parse()
        assert_matches_type(ActionDisableResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_disable(self, client: Telnyx) -> None:
        with client.sim_cards.actions.with_streaming_response.disable(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = response.parse()
            assert_matches_type(ActionDisableResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_disable(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.sim_cards.actions.with_raw_response.disable(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_enable(self, client: Telnyx) -> None:
        action = client.sim_cards.actions.enable(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )
        assert_matches_type(ActionEnableResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_enable(self, client: Telnyx) -> None:
        response = client.sim_cards.actions.with_raw_response.enable(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = response.parse()
        assert_matches_type(ActionEnableResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_enable(self, client: Telnyx) -> None:
        with client.sim_cards.actions.with_streaming_response.enable(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = response.parse()
            assert_matches_type(ActionEnableResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_enable(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.sim_cards.actions.with_raw_response.enable(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_remove_public_ip(self, client: Telnyx) -> None:
        action = client.sim_cards.actions.remove_public_ip(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )
        assert_matches_type(ActionRemovePublicIPResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_remove_public_ip(self, client: Telnyx) -> None:
        response = client.sim_cards.actions.with_raw_response.remove_public_ip(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = response.parse()
        assert_matches_type(ActionRemovePublicIPResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_remove_public_ip(self, client: Telnyx) -> None:
        with client.sim_cards.actions.with_streaming_response.remove_public_ip(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = response.parse()
            assert_matches_type(ActionRemovePublicIPResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_remove_public_ip(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.sim_cards.actions.with_raw_response.remove_public_ip(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_set_public_ip(self, client: Telnyx) -> None:
        action = client.sim_cards.actions.set_public_ip(
            id="6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )
        assert_matches_type(ActionSetPublicIPResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_set_public_ip_with_all_params(self, client: Telnyx) -> None:
        action = client.sim_cards.actions.set_public_ip(
            id="6a09cdc3-8948-47f0-aa62-74ac943d6c58",
            region_code="dc2",
        )
        assert_matches_type(ActionSetPublicIPResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_set_public_ip(self, client: Telnyx) -> None:
        response = client.sim_cards.actions.with_raw_response.set_public_ip(
            id="6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = response.parse()
        assert_matches_type(ActionSetPublicIPResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_set_public_ip(self, client: Telnyx) -> None:
        with client.sim_cards.actions.with_streaming_response.set_public_ip(
            id="6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = response.parse()
            assert_matches_type(ActionSetPublicIPResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_set_public_ip(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.sim_cards.actions.with_raw_response.set_public_ip(
                id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_set_standby(self, client: Telnyx) -> None:
        action = client.sim_cards.actions.set_standby(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )
        assert_matches_type(ActionSetStandbyResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_set_standby(self, client: Telnyx) -> None:
        response = client.sim_cards.actions.with_raw_response.set_standby(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = response.parse()
        assert_matches_type(ActionSetStandbyResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_set_standby(self, client: Telnyx) -> None:
        with client.sim_cards.actions.with_streaming_response.set_standby(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = response.parse()
            assert_matches_type(ActionSetStandbyResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_set_standby(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.sim_cards.actions.with_raw_response.set_standby(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_validate_registration_codes(self, client: Telnyx) -> None:
        action = client.sim_cards.actions.validate_registration_codes()
        assert_matches_type(ActionValidateRegistrationCodesResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_validate_registration_codes_with_all_params(self, client: Telnyx) -> None:
        action = client.sim_cards.actions.validate_registration_codes(
            registration_codes=["123456780", "1231231230"],
        )
        assert_matches_type(ActionValidateRegistrationCodesResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_validate_registration_codes(self, client: Telnyx) -> None:
        response = client.sim_cards.actions.with_raw_response.validate_registration_codes()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = response.parse()
        assert_matches_type(ActionValidateRegistrationCodesResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_validate_registration_codes(self, client: Telnyx) -> None:
        with client.sim_cards.actions.with_streaming_response.validate_registration_codes() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = response.parse()
            assert_matches_type(ActionValidateRegistrationCodesResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncActions:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.sim_cards.actions.retrieve(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )
        assert_matches_type(ActionRetrieveResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.sim_cards.actions.with_raw_response.retrieve(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = await response.parse()
        assert_matches_type(ActionRetrieveResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        async with async_client.sim_cards.actions.with_streaming_response.retrieve(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = await response.parse()
            assert_matches_type(ActionRetrieveResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.sim_cards.actions.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.sim_cards.actions.list()
        assert_matches_type(AsyncDefaultFlatPagination[SimCardAction], action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.sim_cards.actions.list(
            filter={
                "action_type": "disable",
                "bulk_sim_card_action_id": "47a1c2b0-cc7b-4ab1-bb98-b33fb0fc61b9",
                "sim_card_id": "47a1c2b0-cc7b-4ab1-bb98-b33fb0fc61b9",
                "status": "in-progress",
            },
            page_number=0,
            page_size=0,
        )
        assert_matches_type(AsyncDefaultFlatPagination[SimCardAction], action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.sim_cards.actions.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = await response.parse()
        assert_matches_type(AsyncDefaultFlatPagination[SimCardAction], action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncTelnyx) -> None:
        async with async_client.sim_cards.actions.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = await response.parse()
            assert_matches_type(AsyncDefaultFlatPagination[SimCardAction], action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_bulk_set_public_ips(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.sim_cards.actions.bulk_set_public_ips(
            sim_card_ids=["6b14e151-8493-4fa1-8664-1cc4e6d14158"],
        )
        assert_matches_type(ActionBulkSetPublicIPsResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_bulk_set_public_ips(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.sim_cards.actions.with_raw_response.bulk_set_public_ips(
            sim_card_ids=["6b14e151-8493-4fa1-8664-1cc4e6d14158"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = await response.parse()
        assert_matches_type(ActionBulkSetPublicIPsResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_bulk_set_public_ips(self, async_client: AsyncTelnyx) -> None:
        async with async_client.sim_cards.actions.with_streaming_response.bulk_set_public_ips(
            sim_card_ids=["6b14e151-8493-4fa1-8664-1cc4e6d14158"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = await response.parse()
            assert_matches_type(ActionBulkSetPublicIPsResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_disable(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.sim_cards.actions.disable(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )
        assert_matches_type(ActionDisableResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_disable(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.sim_cards.actions.with_raw_response.disable(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = await response.parse()
        assert_matches_type(ActionDisableResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_disable(self, async_client: AsyncTelnyx) -> None:
        async with async_client.sim_cards.actions.with_streaming_response.disable(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = await response.parse()
            assert_matches_type(ActionDisableResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_disable(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.sim_cards.actions.with_raw_response.disable(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_enable(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.sim_cards.actions.enable(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )
        assert_matches_type(ActionEnableResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_enable(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.sim_cards.actions.with_raw_response.enable(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = await response.parse()
        assert_matches_type(ActionEnableResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_enable(self, async_client: AsyncTelnyx) -> None:
        async with async_client.sim_cards.actions.with_streaming_response.enable(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = await response.parse()
            assert_matches_type(ActionEnableResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_enable(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.sim_cards.actions.with_raw_response.enable(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_remove_public_ip(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.sim_cards.actions.remove_public_ip(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )
        assert_matches_type(ActionRemovePublicIPResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_remove_public_ip(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.sim_cards.actions.with_raw_response.remove_public_ip(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = await response.parse()
        assert_matches_type(ActionRemovePublicIPResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_remove_public_ip(self, async_client: AsyncTelnyx) -> None:
        async with async_client.sim_cards.actions.with_streaming_response.remove_public_ip(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = await response.parse()
            assert_matches_type(ActionRemovePublicIPResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_remove_public_ip(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.sim_cards.actions.with_raw_response.remove_public_ip(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_set_public_ip(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.sim_cards.actions.set_public_ip(
            id="6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )
        assert_matches_type(ActionSetPublicIPResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_set_public_ip_with_all_params(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.sim_cards.actions.set_public_ip(
            id="6a09cdc3-8948-47f0-aa62-74ac943d6c58",
            region_code="dc2",
        )
        assert_matches_type(ActionSetPublicIPResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_set_public_ip(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.sim_cards.actions.with_raw_response.set_public_ip(
            id="6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = await response.parse()
        assert_matches_type(ActionSetPublicIPResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_set_public_ip(self, async_client: AsyncTelnyx) -> None:
        async with async_client.sim_cards.actions.with_streaming_response.set_public_ip(
            id="6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = await response.parse()
            assert_matches_type(ActionSetPublicIPResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_set_public_ip(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.sim_cards.actions.with_raw_response.set_public_ip(
                id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_set_standby(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.sim_cards.actions.set_standby(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )
        assert_matches_type(ActionSetStandbyResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_set_standby(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.sim_cards.actions.with_raw_response.set_standby(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = await response.parse()
        assert_matches_type(ActionSetStandbyResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_set_standby(self, async_client: AsyncTelnyx) -> None:
        async with async_client.sim_cards.actions.with_streaming_response.set_standby(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = await response.parse()
            assert_matches_type(ActionSetStandbyResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_set_standby(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.sim_cards.actions.with_raw_response.set_standby(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_validate_registration_codes(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.sim_cards.actions.validate_registration_codes()
        assert_matches_type(ActionValidateRegistrationCodesResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_validate_registration_codes_with_all_params(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.sim_cards.actions.validate_registration_codes(
            registration_codes=["123456780", "1231231230"],
        )
        assert_matches_type(ActionValidateRegistrationCodesResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_validate_registration_codes(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.sim_cards.actions.with_raw_response.validate_registration_codes()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = await response.parse()
        assert_matches_type(ActionValidateRegistrationCodesResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_validate_registration_codes(self, async_client: AsyncTelnyx) -> None:
        async with async_client.sim_cards.actions.with_streaming_response.validate_registration_codes() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = await response.parse()
            assert_matches_type(ActionValidateRegistrationCodesResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import httpx
import pytest
from respx import MockRouter

from telnyx import Telnyx, AsyncTelnyx
from tests.utils import assert_matches_type
from telnyx.types.ai import (
    ClusterListResponse,
    ClusterComputeResponse,
    ClusterRetrieveResponse,
)
from telnyx._response import (
    BinaryAPIResponse,
    AsyncBinaryAPIResponse,
    StreamedBinaryAPIResponse,
    AsyncStreamedBinaryAPIResponse,
)
from telnyx.pagination import SyncDefaultFlatPagination, AsyncDefaultFlatPagination

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestClusters:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: Telnyx) -> None:
        cluster = client.ai.clusters.retrieve(
            task_id="task_id",
        )
        assert_matches_type(ClusterRetrieveResponse, cluster, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve_with_all_params(self, client: Telnyx) -> None:
        cluster = client.ai.clusters.retrieve(
            task_id="task_id",
            show_subclusters=True,
            top_n_nodes=0,
        )
        assert_matches_type(ClusterRetrieveResponse, cluster, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: Telnyx) -> None:
        response = client.ai.clusters.with_raw_response.retrieve(
            task_id="task_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        cluster = response.parse()
        assert_matches_type(ClusterRetrieveResponse, cluster, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: Telnyx) -> None:
        with client.ai.clusters.with_streaming_response.retrieve(
            task_id="task_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            cluster = response.parse()
            assert_matches_type(ClusterRetrieveResponse, cluster, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `task_id` but received ''"):
            client.ai.clusters.with_raw_response.retrieve(
                task_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list(self, client: Telnyx) -> None:
        cluster = client.ai.clusters.list()
        assert_matches_type(SyncDefaultFlatPagination[ClusterListResponse], cluster, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: Telnyx) -> None:
        cluster = client.ai.clusters.list(
            page_number=0,
            page_size=0,
        )
        assert_matches_type(SyncDefaultFlatPagination[ClusterListResponse], cluster, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Telnyx) -> None:
        response = client.ai.clusters.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        cluster = response.parse()
        assert_matches_type(SyncDefaultFlatPagination[ClusterListResponse], cluster, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Telnyx) -> None:
        with client.ai.clusters.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            cluster = response.parse()
            assert_matches_type(SyncDefaultFlatPagination[ClusterListResponse], cluster, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_delete(self, client: Telnyx) -> None:
        cluster = client.ai.clusters.delete(
            "task_id",
        )
        assert cluster is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_delete(self, client: Telnyx) -> None:
        response = client.ai.clusters.with_raw_response.delete(
            "task_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        cluster = response.parse()
        assert cluster is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_delete(self, client: Telnyx) -> None:
        with client.ai.clusters.with_streaming_response.delete(
            "task_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            cluster = response.parse()
            assert cluster is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_delete(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `task_id` but received ''"):
            client.ai.clusters.with_raw_response.delete(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_compute(self, client: Telnyx) -> None:
        cluster = client.ai.clusters.compute(
            bucket="bucket",
        )
        assert_matches_type(ClusterComputeResponse, cluster, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_compute_with_all_params(self, client: Telnyx) -> None:
        cluster = client.ai.clusters.compute(
            bucket="bucket",
            files=["string"],
            min_cluster_size=0,
            min_subcluster_size=0,
            prefix="prefix",
        )
        assert_matches_type(ClusterComputeResponse, cluster, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_compute(self, client: Telnyx) -> None:
        response = client.ai.clusters.with_raw_response.compute(
            bucket="bucket",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        cluster = response.parse()
        assert_matches_type(ClusterComputeResponse, cluster, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_compute(self, client: Telnyx) -> None:
        with client.ai.clusters.with_streaming_response.compute(
            bucket="bucket",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            cluster = response.parse()
            assert_matches_type(ClusterComputeResponse, cluster, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_method_fetch_graph(self, client: Telnyx, respx_mock: MockRouter) -> None:
        respx_mock.get("/ai/clusters/task_id/graph").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        cluster = client.ai.clusters.fetch_graph(
            task_id="task_id",
        )
        assert cluster.is_closed
        assert cluster.json() == {"foo": "bar"}
        assert cast(Any, cluster.is_closed) is True
        assert isinstance(cluster, BinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_method_fetch_graph_with_all_params(self, client: Telnyx, respx_mock: MockRouter) -> None:
        respx_mock.get("/ai/clusters/task_id/graph").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        cluster = client.ai.clusters.fetch_graph(
            task_id="task_id",
            cluster_id=0,
        )
        assert cluster.is_closed
        assert cluster.json() == {"foo": "bar"}
        assert cast(Any, cluster.is_closed) is True
        assert isinstance(cluster, BinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_raw_response_fetch_graph(self, client: Telnyx, respx_mock: MockRouter) -> None:
        respx_mock.get("/ai/clusters/task_id/graph").mock(return_value=httpx.Response(200, json={"foo": "bar"}))

        cluster = client.ai.clusters.with_raw_response.fetch_graph(
            task_id="task_id",
        )

        assert cluster.is_closed is True
        assert cluster.http_request.headers.get("X-Stainless-Lang") == "python"
        assert cluster.json() == {"foo": "bar"}
        assert isinstance(cluster, BinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_streaming_response_fetch_graph(self, client: Telnyx, respx_mock: MockRouter) -> None:
        respx_mock.get("/ai/clusters/task_id/graph").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        with client.ai.clusters.with_streaming_response.fetch_graph(
            task_id="task_id",
        ) as cluster:
            assert not cluster.is_closed
            assert cluster.http_request.headers.get("X-Stainless-Lang") == "python"

            assert cluster.json() == {"foo": "bar"}
            assert cast(Any, cluster.is_closed) is True
            assert isinstance(cluster, StreamedBinaryAPIResponse)

        assert cast(Any, cluster.is_closed) is True

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_path_params_fetch_graph(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `task_id` but received ''"):
            client.ai.clusters.with_raw_response.fetch_graph(
                task_id="",
            )


class TestAsyncClusters:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncTelnyx) -> None:
        cluster = await async_client.ai.clusters.retrieve(
            task_id="task_id",
        )
        assert_matches_type(ClusterRetrieveResponse, cluster, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve_with_all_params(self, async_client: AsyncTelnyx) -> None:
        cluster = await async_client.ai.clusters.retrieve(
            task_id="task_id",
            show_subclusters=True,
            top_n_nodes=0,
        )
        assert_matches_type(ClusterRetrieveResponse, cluster, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.clusters.with_raw_response.retrieve(
            task_id="task_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        cluster = await response.parse()
        assert_matches_type(ClusterRetrieveResponse, cluster, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.clusters.with_streaming_response.retrieve(
            task_id="task_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            cluster = await response.parse()
            assert_matches_type(ClusterRetrieveResponse, cluster, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `task_id` but received ''"):
            await async_client.ai.clusters.with_raw_response.retrieve(
                task_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncTelnyx) -> None:
        cluster = await async_client.ai.clusters.list()
        assert_matches_type(AsyncDefaultFlatPagination[ClusterListResponse], cluster, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncTelnyx) -> None:
        cluster = await async_client.ai.clusters.list(
            page_number=0,
            page_size=0,
        )
        assert_matches_type(AsyncDefaultFlatPagination[ClusterListResponse], cluster, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.clusters.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        cluster = await response.parse()
        assert_matches_type(AsyncDefaultFlatPagination[ClusterListResponse], cluster, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.clusters.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            cluster = await response.parse()
            assert_matches_type(AsyncDefaultFlatPagination[ClusterListResponse], cluster, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_delete(self, async_client: AsyncTelnyx) -> None:
        cluster = await async_client.ai.clusters.delete(
            "task_id",
        )
        assert cluster is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.clusters.with_raw_response.delete(
            "task_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        cluster = await response.parse()
        assert cluster is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.clusters.with_streaming_response.delete(
            "task_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            cluster = await response.parse()
            assert cluster is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_delete(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `task_id` but received ''"):
            await async_client.ai.clusters.with_raw_response.delete(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_compute(self, async_client: AsyncTelnyx) -> None:
        cluster = await async_client.ai.clusters.compute(
            bucket="bucket",
        )
        assert_matches_type(ClusterComputeResponse, cluster, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_compute_with_all_params(self, async_client: AsyncTelnyx) -> None:
        cluster = await async_client.ai.clusters.compute(
            bucket="bucket",
            files=["string"],
            min_cluster_size=0,
            min_subcluster_size=0,
            prefix="prefix",
        )
        assert_matches_type(ClusterComputeResponse, cluster, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_compute(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.clusters.with_raw_response.compute(
            bucket="bucket",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        cluster = await response.parse()
        assert_matches_type(ClusterComputeResponse, cluster, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_compute(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.clusters.with_streaming_response.compute(
            bucket="bucket",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            cluster = await response.parse()
            assert_matches_type(ClusterComputeResponse, cluster, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_method_fetch_graph(self, async_client: AsyncTelnyx, respx_mock: MockRouter) -> None:
        respx_mock.get("/ai/clusters/task_id/graph").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        cluster = await async_client.ai.clusters.fetch_graph(
            task_id="task_id",
        )
        assert cluster.is_closed
        assert await cluster.json() == {"foo": "bar"}
        assert cast(Any, cluster.is_closed) is True
        assert isinstance(cluster, AsyncBinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_method_fetch_graph_with_all_params(self, async_client: AsyncTelnyx, respx_mock: MockRouter) -> None:
        respx_mock.get("/ai/clusters/task_id/graph").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        cluster = await async_client.ai.clusters.fetch_graph(
            task_id="task_id",
            cluster_id=0,
        )
        assert cluster.is_closed
        assert await cluster.json() == {"foo": "bar"}
        assert cast(Any, cluster.is_closed) is True
        assert isinstance(cluster, AsyncBinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_raw_response_fetch_graph(self, async_client: AsyncTelnyx, respx_mock: MockRouter) -> None:
        respx_mock.get("/ai/clusters/task_id/graph").mock(return_value=httpx.Response(200, json={"foo": "bar"}))

        cluster = await async_client.ai.clusters.with_raw_response.fetch_graph(
            task_id="task_id",
        )

        assert cluster.is_closed is True
        assert cluster.http_request.headers.get("X-Stainless-Lang") == "python"
        assert await cluster.json() == {"foo": "bar"}
        assert isinstance(cluster, AsyncBinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_streaming_response_fetch_graph(self, async_client: AsyncTelnyx, respx_mock: MockRouter) -> None:
        respx_mock.get("/ai/clusters/task_id/graph").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        async with async_client.ai.clusters.with_streaming_response.fetch_graph(
            task_id="task_id",
        ) as cluster:
            assert not cluster.is_closed
            assert cluster.http_request.headers.get("X-Stainless-Lang") == "python"

            assert await cluster.json() == {"foo": "bar"}
            assert cast(Any, cluster.is_closed) is True
            assert isinstance(cluster, AsyncStreamedBinaryAPIResponse)

        assert cast(Any, cluster.is_closed) is True

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_path_params_fetch_graph(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `task_id` but received ''"):
            await async_client.ai.clusters.with_raw_response.fetch_graph(
                task_id="",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import date

from ..._models import BaseModel

__all__ = ["UserBundleResource"]


class UserBundleResource(BaseModel):
    id: str
    """Resource's ID."""

    created_at: date
    """Date the resource was created."""

    resource: str
    """The resource itself (usually a phone number)."""

    resource_type: str
    """The type of the resource (usually 'number')."""

    updated_at: Optional[date] = None
    """Date the resource was last updated."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["CallRetrieveStatusResponse", "Data"]


class Data(BaseModel):
    call_control_id: str
    """Unique identifier and token for controlling the call."""

    call_leg_id: str
    """ID that is unique to the call and can be used to correlate webhook events"""

    call_session_id: str
    """
    ID that is unique to the call session and can be used to correlate webhook
    events. Call session is a group of related call legs that logically belong to
    the same phone call, e.g. an inbound and outbound leg of a transferred call
    """

    is_alive: bool
    """Indicates whether the call is alive or not.

    For Dial command it will always be `false` (dialing is asynchronous).
    """

    record_type: Literal["call"]

    call_duration: Optional[int] = None
    """Indicates the duration of the call in seconds"""

    client_state: Optional[str] = None
    """State received from a command."""

    end_time: Optional[str] = None
    """ISO 8601 formatted date indicating when the call ended.

    Only present when the call is not alive
    """

    start_time: Optional[str] = None
    """ISO 8601 formatted date indicating when the call started"""


class CallRetrieveStatusResponse(BaseModel):
    data: Optional[Data] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .verify_profile_message_template_response import VerifyProfileMessageTemplateResponse

__all__ = ["MessageTemplate"]


class MessageTemplate(BaseModel):
    data: Optional[VerifyProfileMessageTemplateResponse] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from .._models import BaseModel
from .storage.buckets.pagination_meta_simple import PaginationMetaSimple

__all__ = ["StorageListMigrationSourceCoverageResponse", "Data"]


class Data(BaseModel):
    provider: Optional[Literal["aws"]] = None
    """Cloud provider from which to migrate data."""

    source_region: Optional[str] = None
    """Provider region from which to migrate data."""


class StorageListMigrationSourceCoverageResponse(BaseModel):
    data: Optional[List[Data]] = None

    meta: Optional[PaginationMetaSimple] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from datetime import datetime

from ..._models import BaseModel
from ..messaging_10dlc.task_status import TaskStatus

__all__ = ["ClusterListResponse"]


class ClusterListResponse(BaseModel):
    bucket: str

    created_at: datetime

    finished_at: datetime

    min_cluster_size: int

    min_subcluster_size: int

    status: TaskStatus

    task_id: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .action_share_params import ActionShareParams as ActionShareParams
from .comment_list_params import CommentListParams as CommentListParams
from .action_share_response import ActionShareResponse as ActionShareResponse
from .comment_create_params import CommentCreateParams as CommentCreateParams
from .comment_list_response import CommentListResponse as CommentListResponse
from .action_cancel_response import ActionCancelResponse as ActionCancelResponse
from .action_confirm_response import ActionConfirmResponse as ActionConfirmResponse
from .comment_create_response import CommentCreateResponse as CommentCreateResponse
from .action_activate_response import ActionActivateResponse as ActionActivateResponse
from .activation_job_list_params import ActivationJobListParams as ActivationJobListParams
from .porting_phone_number_block import PortingPhoneNumberBlock as PortingPhoneNumberBlock
from .activation_job_update_params import ActivationJobUpdateParams as ActivationJobUpdateParams
from .verification_code_list_params import VerificationCodeListParams as VerificationCodeListParams
from .verification_code_send_params import VerificationCodeSendParams as VerificationCodeSendParams
from .action_requirement_list_params import ActionRequirementListParams as ActionRequirementListParams
from .activation_job_update_response import ActivationJobUpdateResponse as ActivationJobUpdateResponse
from .phone_number_block_list_params import PhoneNumberBlockListParams as PhoneNumberBlockListParams
from .porting_phone_number_extension import PortingPhoneNumberExtension as PortingPhoneNumberExtension
from .additional_document_list_params import AdditionalDocumentListParams as AdditionalDocumentListParams
from .porting_associated_phone_number import PortingAssociatedPhoneNumber as PortingAssociatedPhoneNumber
from .verification_code_list_response import VerificationCodeListResponse as VerificationCodeListResponse
from .verification_code_verify_params import VerificationCodeVerifyParams as VerificationCodeVerifyParams
from .action_requirement_list_response import ActionRequirementListResponse as ActionRequirementListResponse
from .activation_job_retrieve_response import ActivationJobRetrieveResponse as ActivationJobRetrieveResponse
from .phone_number_block_create_params import PhoneNumberBlockCreateParams as PhoneNumberBlockCreateParams
from .additional_document_create_params import AdditionalDocumentCreateParams as AdditionalDocumentCreateParams
from .additional_document_list_response import AdditionalDocumentListResponse as AdditionalDocumentListResponse
from .verification_code_verify_response import VerificationCodeVerifyResponse as VerificationCodeVerifyResponse
from .action_requirement_initiate_params import ActionRequirementInitiateParams as ActionRequirementInitiateParams
from .phone_number_block_create_response import PhoneNumberBlockCreateResponse as PhoneNumberBlockCreateResponse
from .phone_number_block_delete_response import PhoneNumberBlockDeleteResponse as PhoneNumberBlockDeleteResponse
from .phone_number_extension_list_params import PhoneNumberExtensionListParams as PhoneNumberExtensionListParams
from .additional_document_create_response import AdditionalDocumentCreateResponse as AdditionalDocumentCreateResponse
from .associated_phone_number_list_params import AssociatedPhoneNumberListParams as AssociatedPhoneNumberListParams
from .action_requirement_initiate_response import ActionRequirementInitiateResponse as ActionRequirementInitiateResponse
from .phone_number_extension_create_params import PhoneNumberExtensionCreateParams as PhoneNumberExtensionCreateParams
from .associated_phone_number_create_params import (
    AssociatedPhoneNumberCreateParams as AssociatedPhoneNumberCreateParams,
)
from .phone_number_configuration_list_params import (
    PhoneNumberConfigurationListParams as PhoneNumberConfigurationListParams,
)
from .phone_number_extension_create_response import (
    PhoneNumberExtensionCreateResponse as PhoneNumberExtensionCreateResponse,
)
from .phone_number_extension_delete_response import (
    PhoneNumberExtensionDeleteResponse as PhoneNumberExtensionDeleteResponse,
)
from .associated_phone_number_create_response import (
    AssociatedPhoneNumberCreateResponse as AssociatedPhoneNumberCreateResponse,
)
from .associated_phone_number_delete_response import (
    AssociatedPhoneNumberDeleteResponse as AssociatedPhoneNumberDeleteResponse,
)
from .phone_number_configuration_create_params import (
    PhoneNumberConfigurationCreateParams as PhoneNumberConfigurationCreateParams,
)
from .phone_number_configuration_list_response import (
    PhoneNumberConfigurationListResponse as PhoneNumberConfigurationListResponse,
)
from .phone_number_configuration_create_response import (
    PhoneNumberConfigurationCreateResponse as PhoneNumberConfigurationCreateResponse,
)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from telnyx import Telnyx, AsyncTelnyx
from tests.utils import assert_matches_type
from telnyx.pagination import SyncPerPagePaginationV2, AsyncPerPagePaginationV2
from telnyx.types.messaging_10dlc import (
    TelnyxCampaignCsp,
    CampaignListResponse,
    CampaignDeactivateResponse,
    CampaignSubmitAppealResponse,
    CampaignAcceptSharingResponse,
    CampaignGetMnoMetadataResponse,
    CampaignGetSharingStatusResponse,
    CampaignGetOperationStatusResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestCampaign:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: Telnyx) -> None:
        campaign = client.messaging_10dlc.campaign.retrieve(
            "campaignId",
        )
        assert_matches_type(TelnyxCampaignCsp, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: Telnyx) -> None:
        response = client.messaging_10dlc.campaign.with_raw_response.retrieve(
            "campaignId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        campaign = response.parse()
        assert_matches_type(TelnyxCampaignCsp, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: Telnyx) -> None:
        with client.messaging_10dlc.campaign.with_streaming_response.retrieve(
            "campaignId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            campaign = response.parse()
            assert_matches_type(TelnyxCampaignCsp, campaign, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `campaign_id` but received ''"):
            client.messaging_10dlc.campaign.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update(self, client: Telnyx) -> None:
        campaign = client.messaging_10dlc.campaign.update(
            campaign_id="campaignId",
        )
        assert_matches_type(TelnyxCampaignCsp, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update_with_all_params(self, client: Telnyx) -> None:
        campaign = client.messaging_10dlc.campaign.update(
            campaign_id="campaignId",
            auto_renewal=True,
            help_message="helpMessage",
            message_flow="messageFlow",
            reseller_id="resellerId",
            sample1="sample1",
            sample2="sample2",
            sample3="sample3",
            sample4="sample4",
            sample5="sample5",
            webhook_failover_url="webhookFailoverURL",
            webhook_url="webhookURL",
        )
        assert_matches_type(TelnyxCampaignCsp, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_update(self, client: Telnyx) -> None:
        response = client.messaging_10dlc.campaign.with_raw_response.update(
            campaign_id="campaignId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        campaign = response.parse()
        assert_matches_type(TelnyxCampaignCsp, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_update(self, client: Telnyx) -> None:
        with client.messaging_10dlc.campaign.with_streaming_response.update(
            campaign_id="campaignId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            campaign = response.parse()
            assert_matches_type(TelnyxCampaignCsp, campaign, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_update(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `campaign_id` but received ''"):
            client.messaging_10dlc.campaign.with_raw_response.update(
                campaign_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list(self, client: Telnyx) -> None:
        campaign = client.messaging_10dlc.campaign.list(
            brand_id="brandId",
        )
        assert_matches_type(SyncPerPagePaginationV2[CampaignListResponse], campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: Telnyx) -> None:
        campaign = client.messaging_10dlc.campaign.list(
            brand_id="brandId",
            page=0,
            records_per_page=0,
            sort="assignedPhoneNumbersCount",
        )
        assert_matches_type(SyncPerPagePaginationV2[CampaignListResponse], campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Telnyx) -> None:
        response = client.messaging_10dlc.campaign.with_raw_response.list(
            brand_id="brandId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        campaign = response.parse()
        assert_matches_type(SyncPerPagePaginationV2[CampaignListResponse], campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Telnyx) -> None:
        with client.messaging_10dlc.campaign.with_streaming_response.list(
            brand_id="brandId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            campaign = response.parse()
            assert_matches_type(SyncPerPagePaginationV2[CampaignListResponse], campaign, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_accept_sharing(self, client: Telnyx) -> None:
        campaign = client.messaging_10dlc.campaign.accept_sharing(
            "C26F1KLZN",
        )
        assert_matches_type(CampaignAcceptSharingResponse, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_accept_sharing(self, client: Telnyx) -> None:
        response = client.messaging_10dlc.campaign.with_raw_response.accept_sharing(
            "C26F1KLZN",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        campaign = response.parse()
        assert_matches_type(CampaignAcceptSharingResponse, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_accept_sharing(self, client: Telnyx) -> None:
        with client.messaging_10dlc.campaign.with_streaming_response.accept_sharing(
            "C26F1KLZN",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            campaign = response.parse()
            assert_matches_type(CampaignAcceptSharingResponse, campaign, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_accept_sharing(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `campaign_id` but received ''"):
            client.messaging_10dlc.campaign.with_raw_response.accept_sharing(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_deactivate(self, client: Telnyx) -> None:
        campaign = client.messaging_10dlc.campaign.deactivate(
            "campaignId",
        )
        assert_matches_type(CampaignDeactivateResponse, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_deactivate(self, client: Telnyx) -> None:
        response = client.messaging_10dlc.campaign.with_raw_response.deactivate(
            "campaignId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        campaign = response.parse()
        assert_matches_type(CampaignDeactivateResponse, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_deactivate(self, client: Telnyx) -> None:
        with client.messaging_10dlc.campaign.with_streaming_response.deactivate(
            "campaignId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            campaign = response.parse()
            assert_matches_type(CampaignDeactivateResponse, campaign, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_deactivate(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `campaign_id` but received ''"):
            client.messaging_10dlc.campaign.with_raw_response.deactivate(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_mno_metadata(self, client: Telnyx) -> None:
        campaign = client.messaging_10dlc.campaign.get_mno_metadata(
            "campaignId",
        )
        assert_matches_type(CampaignGetMnoMetadataResponse, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get_mno_metadata(self, client: Telnyx) -> None:
        response = client.messaging_10dlc.campaign.with_raw_response.get_mno_metadata(
            "campaignId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        campaign = response.parse()
        assert_matches_type(CampaignGetMnoMetadataResponse, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get_mno_metadata(self, client: Telnyx) -> None:
        with client.messaging_10dlc.campaign.with_streaming_response.get_mno_metadata(
            "campaignId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            campaign = response.parse()
            assert_matches_type(CampaignGetMnoMetadataResponse, campaign, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_get_mno_metadata(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `campaign_id` but received ''"):
            client.messaging_10dlc.campaign.with_raw_response.get_mno_metadata(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_operation_status(self, client: Telnyx) -> None:
        campaign = client.messaging_10dlc.campaign.get_operation_status(
            "campaignId",
        )
        assert_matches_type(CampaignGetOperationStatusResponse, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get_operation_status(self, client: Telnyx) -> None:
        response = client.messaging_10dlc.campaign.with_raw_response.get_operation_status(
            "campaignId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        campaign = response.parse()
        assert_matches_type(CampaignGetOperationStatusResponse, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get_operation_status(self, client: Telnyx) -> None:
        with client.messaging_10dlc.campaign.with_streaming_response.get_operation_status(
            "campaignId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            campaign = response.parse()
            assert_matches_type(CampaignGetOperationStatusResponse, campaign, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_get_operation_status(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `campaign_id` but received ''"):
            client.messaging_10dlc.campaign.with_raw_response.get_operation_status(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_sharing_status(self, client: Telnyx) -> None:
        campaign = client.messaging_10dlc.campaign.get_sharing_status(
            "campaignId",
        )
        assert_matches_type(CampaignGetSharingStatusResponse, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get_sharing_status(self, client: Telnyx) -> None:
        response = client.messaging_10dlc.campaign.with_raw_response.get_sharing_status(
            "campaignId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        campaign = response.parse()
        assert_matches_type(CampaignGetSharingStatusResponse, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get_sharing_status(self, client: Telnyx) -> None:
        with client.messaging_10dlc.campaign.with_streaming_response.get_sharing_status(
            "campaignId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            campaign = response.parse()
            assert_matches_type(CampaignGetSharingStatusResponse, campaign, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_get_sharing_status(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `campaign_id` but received ''"):
            client.messaging_10dlc.campaign.with_raw_response.get_sharing_status(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_submit_appeal(self, client: Telnyx) -> None:
        campaign = client.messaging_10dlc.campaign.submit_appeal(
            campaign_id="5eb13888-32b7-4cab-95e6-d834dde21d64",
            appeal_reason="The website has been updated to include the required privacy policy and terms of service.",
        )
        assert_matches_type(CampaignSubmitAppealResponse, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_submit_appeal(self, client: Telnyx) -> None:
        response = client.messaging_10dlc.campaign.with_raw_response.submit_appeal(
            campaign_id="5eb13888-32b7-4cab-95e6-d834dde21d64",
            appeal_reason="The website has been updated to include the required privacy policy and terms of service.",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        campaign = response.parse()
        assert_matches_type(CampaignSubmitAppealResponse, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_submit_appeal(self, client: Telnyx) -> None:
        with client.messaging_10dlc.campaign.with_streaming_response.submit_appeal(
            campaign_id="5eb13888-32b7-4cab-95e6-d834dde21d64",
            appeal_reason="The website has been updated to include the required privacy policy and terms of service.",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            campaign = response.parse()
            assert_matches_type(CampaignSubmitAppealResponse, campaign, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_submit_appeal(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `campaign_id` but received ''"):
            client.messaging_10dlc.campaign.with_raw_response.submit_appeal(
                campaign_id="",
                appeal_reason="The website has been updated to include the required privacy policy and terms of service.",
            )


class TestAsyncCampaign:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncTelnyx) -> None:
        campaign = await async_client.messaging_10dlc.campaign.retrieve(
            "campaignId",
        )
        assert_matches_type(TelnyxCampaignCsp, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.messaging_10dlc.campaign.with_raw_response.retrieve(
            "campaignId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        campaign = await response.parse()
        assert_matches_type(TelnyxCampaignCsp, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        async with async_client.messaging_10dlc.campaign.with_streaming_response.retrieve(
            "campaignId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            campaign = await response.parse()
            assert_matches_type(TelnyxCampaignCsp, campaign, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `campaign_id` but received ''"):
            await async_client.messaging_10dlc.campaign.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update(self, async_client: AsyncTelnyx) -> None:
        campaign = await async_client.messaging_10dlc.campaign.update(
            campaign_id="campaignId",
        )
        assert_matches_type(TelnyxCampaignCsp, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncTelnyx) -> None:
        campaign = await async_client.messaging_10dlc.campaign.update(
            campaign_id="campaignId",
            auto_renewal=True,
            help_message="helpMessage",
            message_flow="messageFlow",
            reseller_id="resellerId",
            sample1="sample1",
            sample2="sample2",
            sample3="sample3",
            sample4="sample4",
            sample5="sample5",
            webhook_failover_url="webhookFailoverURL",
            webhook_url="webhookURL",
        )
        assert_matches_type(TelnyxCampaignCsp, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.messaging_10dlc.campaign.with_raw_response.update(
            campaign_id="campaignId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        campaign = await response.parse()
        assert_matches_type(TelnyxCampaignCsp, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncTelnyx) -> None:
        async with async_client.messaging_10dlc.campaign.with_streaming_response.update(
            campaign_id="campaignId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            campaign = await response.parse()
            assert_matches_type(TelnyxCampaignCsp, campaign, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_update(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `campaign_id` but received ''"):
            await async_client.messaging_10dlc.campaign.with_raw_response.update(
                campaign_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncTelnyx) -> None:
        campaign = await async_client.messaging_10dlc.campaign.list(
            brand_id="brandId",
        )
        assert_matches_type(AsyncPerPagePaginationV2[CampaignListResponse], campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncTelnyx) -> None:
        campaign = await async_client.messaging_10dlc.campaign.list(
            brand_id="brandId",
            page=0,
            records_per_page=0,
            sort="assignedPhoneNumbersCount",
        )
        assert_matches_type(AsyncPerPagePaginationV2[CampaignListResponse], campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.messaging_10dlc.campaign.with_raw_response.list(
            brand_id="brandId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        campaign = await response.parse()
        assert_matches_type(AsyncPerPagePaginationV2[CampaignListResponse], campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncTelnyx) -> None:
        async with async_client.messaging_10dlc.campaign.with_streaming_response.list(
            brand_id="brandId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            campaign = await response.parse()
            assert_matches_type(AsyncPerPagePaginationV2[CampaignListResponse], campaign, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_accept_sharing(self, async_client: AsyncTelnyx) -> None:
        campaign = await async_client.messaging_10dlc.campaign.accept_sharing(
            "C26F1KLZN",
        )
        assert_matches_type(CampaignAcceptSharingResponse, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_accept_sharing(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.messaging_10dlc.campaign.with_raw_response.accept_sharing(
            "C26F1KLZN",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        campaign = await response.parse()
        assert_matches_type(CampaignAcceptSharingResponse, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_accept_sharing(self, async_client: AsyncTelnyx) -> None:
        async with async_client.messaging_10dlc.campaign.with_streaming_response.accept_sharing(
            "C26F1KLZN",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            campaign = await response.parse()
            assert_matches_type(CampaignAcceptSharingResponse, campaign, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_accept_sharing(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `campaign_id` but received ''"):
            await async_client.messaging_10dlc.campaign.with_raw_response.accept_sharing(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_deactivate(self, async_client: AsyncTelnyx) -> None:
        campaign = await async_client.messaging_10dlc.campaign.deactivate(
            "campaignId",
        )
        assert_matches_type(CampaignDeactivateResponse, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_deactivate(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.messaging_10dlc.campaign.with_raw_response.deactivate(
            "campaignId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        campaign = await response.parse()
        assert_matches_type(CampaignDeactivateResponse, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_deactivate(self, async_client: AsyncTelnyx) -> None:
        async with async_client.messaging_10dlc.campaign.with_streaming_response.deactivate(
            "campaignId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            campaign = await response.parse()
            assert_matches_type(CampaignDeactivateResponse, campaign, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_deactivate(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `campaign_id` but received ''"):
            await async_client.messaging_10dlc.campaign.with_raw_response.deactivate(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_mno_metadata(self, async_client: AsyncTelnyx) -> None:
        campaign = await async_client.messaging_10dlc.campaign.get_mno_metadata(
            "campaignId",
        )
        assert_matches_type(CampaignGetMnoMetadataResponse, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get_mno_metadata(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.messaging_10dlc.campaign.with_raw_response.get_mno_metadata(
            "campaignId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        campaign = await response.parse()
        assert_matches_type(CampaignGetMnoMetadataResponse, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get_mno_metadata(self, async_client: AsyncTelnyx) -> None:
        async with async_client.messaging_10dlc.campaign.with_streaming_response.get_mno_metadata(
            "campaignId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            campaign = await response.parse()
            assert_matches_type(CampaignGetMnoMetadataResponse, campaign, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_get_mno_metadata(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `campaign_id` but received ''"):
            await async_client.messaging_10dlc.campaign.with_raw_response.get_mno_metadata(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_operation_status(self, async_client: AsyncTelnyx) -> None:
        campaign = await async_client.messaging_10dlc.campaign.get_operation_status(
            "campaignId",
        )
        assert_matches_type(CampaignGetOperationStatusResponse, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get_operation_status(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.messaging_10dlc.campaign.with_raw_response.get_operation_status(
            "campaignId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        campaign = await response.parse()
        assert_matches_type(CampaignGetOperationStatusResponse, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get_operation_status(self, async_client: AsyncTelnyx) -> None:
        async with async_client.messaging_10dlc.campaign.with_streaming_response.get_operation_status(
            "campaignId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            campaign = await response.parse()
            assert_matches_type(CampaignGetOperationStatusResponse, campaign, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_get_operation_status(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `campaign_id` but received ''"):
            await async_client.messaging_10dlc.campaign.with_raw_response.get_operation_status(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_sharing_status(self, async_client: AsyncTelnyx) -> None:
        campaign = await async_client.messaging_10dlc.campaign.get_sharing_status(
            "campaignId",
        )
        assert_matches_type(CampaignGetSharingStatusResponse, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get_sharing_status(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.messaging_10dlc.campaign.with_raw_response.get_sharing_status(
            "campaignId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        campaign = await response.parse()
        assert_matches_type(CampaignGetSharingStatusResponse, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get_sharing_status(self, async_client: AsyncTelnyx) -> None:
        async with async_client.messaging_10dlc.campaign.with_streaming_response.get_sharing_status(
            "campaignId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            campaign = await response.parse()
            assert_matches_type(CampaignGetSharingStatusResponse, campaign, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_get_sharing_status(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `campaign_id` but received ''"):
            await async_client.messaging_10dlc.campaign.with_raw_response.get_sharing_status(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_submit_appeal(self, async_client: AsyncTelnyx) -> None:
        campaign = await async_client.messaging_10dlc.campaign.submit_appeal(
            campaign_id="5eb13888-32b7-4cab-95e6-d834dde21d64",
            appeal_reason="The website has been updated to include the required privacy policy and terms of service.",
        )
        assert_matches_type(CampaignSubmitAppealResponse, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_submit_appeal(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.messaging_10dlc.campaign.with_raw_response.submit_appeal(
            campaign_id="5eb13888-32b7-4cab-95e6-d834dde21d64",
            appeal_reason="The website has been updated to include the required privacy policy and terms of service.",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        campaign = await response.parse()
        assert_matches_type(CampaignSubmitAppealResponse, campaign, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_submit_appeal(self, async_client: AsyncTelnyx) -> None:
        async with async_client.messaging_10dlc.campaign.with_streaming_response.submit_appeal(
            campaign_id="5eb13888-32b7-4cab-95e6-d834dde21d64",
            appeal_reason="The website has been updated to include the required privacy policy and terms of service.",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            campaign = await response.parse()
            assert_matches_type(CampaignSubmitAppealResponse, campaign, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_submit_appeal(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `campaign_id` but received ''"):
            await async_client.messaging_10dlc.campaign.with_raw_response.submit_appeal(
                campaign_id="",
                appeal_reason="The website has been updated to include the required privacy policy and terms of service.",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["BrandIdentityStatus"]

BrandIdentityStatus: TypeAlias = Literal["VERIFIED", "UNVERIFIED", "SELF_DECLARED", "VETTED_VERIFIED"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional
from datetime import datetime
from typing_extensions import Literal

from ..._models import BaseModel
from .assistant_tool import AssistantTool
from .voice_settings import VoiceSettings
from .import_metadata import ImportMetadata
from .enabled_features import EnabledFeatures
from .insight_settings import InsightSettings
from .privacy_settings import PrivacySettings
from .messaging_settings import MessagingSettings
from .telephony_settings import TelephonySettings
from .transcription_settings import TranscriptionSettings

__all__ = ["InferenceEmbedding", "WidgetSettings", "WidgetSettingsAudioVisualizerConfig"]


class WidgetSettingsAudioVisualizerConfig(BaseModel):
    color: Optional[Literal["verdant", "twilight", "bloom", "mystic", "flare", "glacier"]] = None
    """The color theme for the audio visualizer."""

    preset: Optional[str] = None
    """The preset style for the audio visualizer."""


class WidgetSettings(BaseModel):
    """Configuration settings for the assistant's web widget."""

    agent_thinking_text: Optional[str] = None
    """Text displayed while the agent is processing."""

    audio_visualizer_config: Optional[WidgetSettingsAudioVisualizerConfig] = None

    default_state: Optional[Literal["expanded", "collapsed"]] = None
    """The default state of the widget."""

    give_feedback_url: Optional[str] = None
    """URL for users to give feedback."""

    logo_icon_url: Optional[str] = None
    """URL to a custom logo icon for the widget."""

    position: Optional[Literal["fixed", "static"]] = None
    """The positioning style for the widget."""

    report_issue_url: Optional[str] = None
    """URL for users to report issues."""

    speak_to_interrupt_text: Optional[str] = None
    """Text prompting users to speak to interrupt."""

    start_call_text: Optional[str] = None
    """Custom text displayed on the start call button."""

    theme: Optional[Literal["light", "dark"]] = None
    """The visual theme for the widget."""

    view_history_url: Optional[str] = None
    """URL to view conversation history."""


class InferenceEmbedding(BaseModel):
    id: str

    created_at: datetime

    instructions: str
    """System instructions for the assistant.

    These may be templated with
    [dynamic variables](https://developers.telnyx.com/docs/inference/ai-assistants/dynamic-variables)
    """

    model: str
    """ID of the model to use.

    You can use the
    [Get models API](https://developers.telnyx.com/api-reference/chat/get-available-models)
    to see all of your available models,
    """

    name: str

    description: Optional[str] = None

    dynamic_variables: Optional[Dict[str, object]] = None
    """Map of dynamic variables and their values"""

    dynamic_variables_webhook_url: Optional[str] = None
    """
    If the dynamic_variables_webhook_url is set for the assistant, we will send a
    request at the start of the conversation. See our
    [guide](https://developers.telnyx.com/docs/inference/ai-assistants/dynamic-variables)
    for more information.
    """

    enabled_features: Optional[List[EnabledFeatures]] = None

    greeting: Optional[str] = None
    """Text that the assistant will use to start the conversation.

    This may be templated with
    [dynamic variables](https://developers.telnyx.com/docs/inference/ai-assistants/dynamic-variables)
    """

    import_metadata: Optional[ImportMetadata] = None

    insight_settings: Optional[InsightSettings] = None

    llm_api_key_ref: Optional[str] = None
    """This is only needed when using third-party inference providers.

    The `identifier` for an integration secret
    [/v2/integration_secrets](https://developers.telnyx.com/api-reference/integration-secrets/create-a-secret)
    that refers to your LLM provider's API key. Warning: Free plans are unlikely to
    work with this integration.
    """

    messaging_settings: Optional[MessagingSettings] = None

    privacy_settings: Optional[PrivacySettings] = None

    telephony_settings: Optional[TelephonySettings] = None

    tools: Optional[List[AssistantTool]] = None
    """The tools that the assistant can use.

    These may be templated with
    [dynamic variables](https://developers.telnyx.com/docs/inference/ai-assistants/dynamic-variables)
    """

    transcription: Optional[TranscriptionSettings] = None

    voice_settings: Optional[VoiceSettings] = None

    widget_settings: Optional[WidgetSettings] = None
    """Configuration settings for the assistant's web widget."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional

from .._models import BaseModel

__all__ = ["GlobalIPHealthCheckTypeListResponse", "Data"]


class Data(BaseModel):
    health_check_params: Optional[Dict[str, object]] = None
    """Global IP Health check params."""

    health_check_type: Optional[str] = None
    """Global IP Health check type."""

    record_type: Optional[str] = None
    """Identifies the type of the resource."""


class GlobalIPHealthCheckTypeListResponse(BaseModel):
    data: Optional[List[Data]] = None
